@@ -10,8 +10,11 @@ import sys
 import textwrap
 
 import pytest
+import sphinx
 from sphinx.application import Sphinx
 
+from tests import helpers # isort:skip
+
 
 def _make_sphinx_project(tmpdir):
     srcdir = tmpdir.mkdir('src')
@@ -54,19 +57,19 @@ def add_file(thedir, filename, content):
         f.write(textwrap.dedent(content))
 
 
-def get_sphinx_app(srcdir, outdir, docname):
+def get_sphinx_app(srcdir, outdir, docname, builder='spelling'):
     stdout = io.StringIO()
     stderr = io.StringIO()
     app = Sphinx(
-        srcdir, srcdir, outdir, outdir, 'spelling',
+        srcdir, srcdir, outdir, outdir, builder,
         status=stdout, warning=stderr,
         freshenv=True,
     )
     return (stdout, stderr, app)
 
 
-def get_sphinx_output(srcdir, outdir, docname):
-    stdout, stderr, app = get_sphinx_app(srcdir, outdir, docname)
+def get_sphinx_output(srcdir, outdir, docname, builder='spelling'):
+    stdout, stderr, app = get_sphinx_app(srcdir, outdir, docname, builder)
     app.build()
     path = os.path.join(outdir, f'{docname}.spelling')
     try:
@@ -251,6 +254,7 @@ def test_ignore_file(sphinx_project):
     assert output_text is None
 
 
+@helpers.require_git_repo
 def test_docstrings(sphinx_project):
     srcdir, outdir = sphinx_project
 
@@ -286,11 +290,17 @@ def test_docstrings(sphinx_project):
                 'contents',
             )
 
+    # Sphinx 5.1.0 and later reports line numbers for docstring
+    # content.
+    line_num = 'None:'
+    if sphinx.version_info[:3] >= (5, 1, 0):
+        line_num = '1:'
+
     # Expected string is too long for one line
     expected = (
         'the_source.py:'
         'docstring of the_source.public_function:'
-        'None:'
+    ) + line_num + (
         ' (vaule)'
     )
     assert expected in output_text
@@ -435,3 +445,30 @@ def test_domain_role_multiple_words(sphinx_project):
         'contents',
     )
     assert output_text is None
+
+def test_domain_role_output(sphinx_project):
+    srcdir, outdir = sphinx_project
+
+    add_file(srcdir, 'contents.rst', '''
+    The Module
+    ==========
+
+    :spelling:word:`teh` is OK
+
+    ''')
+
+    stdout, stderr, output_text = get_sphinx_output(
+        srcdir,
+        outdir,
+        'contents',
+        'text',
+    )
+
+    path = os.path.join(outdir, 'contents.txt')
+    try:
+        with open(path, 'r') as f:
+            output_text = f.read()
+    except FileNotFoundError:
+        output_text = None
+
+    assert output_text == "The Module\n**********\n\nteh is OK\n"
